#include "char_generator_factory.hpp"

#include "char_generator/numeric_char_generator.hpp"
#include "char_generator/alphabetic_char_generator.hpp"
#include "char_generator/alphanumeric_char_generator.hpp"

CharGeneratorFactory::CharGeneratorFactory()
{
    insert("Numeric", std::make_shared<NumericCharGenerator>());
    insert("Alphabetic", std::make_shared<AlphabeticCharGenerator>());
    insert("Alphanumeric", std::make_shared<AlphanumericCharGenerator>());
}

std::vector<std::string> CharGeneratorFactory::getCharGeneratorNames() const
{
    auto names = std::vector<std::string>();

    for (auto& pair : charGeneratorsMap_)
    {
        names.push_back(pair.first);
    }

    return names;
}

CharGeneratorPtr CharGeneratorFactory::getGenerator(const std::string name)  const
{
    return charGeneratorsMap_.find(name)->second;
}

CharGeneratorPtr CharGeneratorFactory::front() const
{
    return charGeneratorsMap_.begin()->second;
}

bool CharGeneratorFactory::insert(std::string name, CharGeneratorPtr generator)
{
    return charGeneratorsMap_.insert(std::make_pair(name, generator)).second;
}
