#include "main_window.hpp"

#include "../core/char_generator_factory.hpp"

#include <ui/ui_main_window.h>

MainWindow::MainWindow(QWidget* parent)
    : QMainWindow(parent)
    , ui(new Ui::MainWindow())
    , passwordGenerator_(CharGeneratorFactory().front())

{
    ui->setupUi(this);

    setupButtons();

    createActions();
}

void MainWindow::createActions()
{
    connect(ui->actionQuit, &QAction::triggered, this, &MainWindow::quit);   

    connect(ui->generateButton, &QPushButton::clicked, this, &MainWindow::calculate);

    connect(ui->comboBox, &QComboBox::currentTextChanged, this, &MainWindow::generatorChanged);
}

void MainWindow::generatorChanged(QString generatorName)
{
    passwordGenerator_.set(CharGeneratorFactory().getGenerator(generatorName.toStdString()));
}

void MainWindow::calculate()
{
    auto password_lenght = ui->passwordLength->value();

    auto password = passwordGenerator_.generate(password_lenght);

    ui->passwordEdit->setPlainText(QString::fromStdString(password.get()));
}

void MainWindow::setupButtons()
{
    ui->passwordLength->setMinimum(1);
    ui->passwordLength->setMaximum(50);
    ui->passwordLength->setValue(10);

    for (auto name : CharGeneratorFactory().getCharGeneratorNames())
    {
        ui->comboBox->addItem(QString::fromStdString(name));
    }
}

void MainWindow::quit()
{
    close();
}

void MainWindow::about()
{
}
